package com.fs.qw.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.qw.domain.QwAppMiniProgramRelation;

/**
 * 应用-小程序关系Service接口
 * 
 * @author fs
 * @date 2026-01-13
 */
public interface IQwAppMiniProgramRelationService extends IService<QwAppMiniProgramRelation>{
    /**
     * 查询应用-小程序关系
     * 
     * @param id 应用-小程序关系主键
     * @return 应用-小程序关系
     */
    QwAppMiniProgramRelation selectQwAppMiniProgramRelationById(Long id);

    /**
     * 查询应用-小程序关系列表
     * 
     * @param qwAppMiniProgramRelation 应用-小程序关系
     * @return 应用-小程序关系集合
     */
    List<QwAppMiniProgramRelation> selectQwAppMiniProgramRelationList(QwAppMiniProgramRelation qwAppMiniProgramRelation);

    /**
     * 新增应用-小程序关系
     * 
     * @param qwAppMiniProgramRelation 应用-小程序关系
     * @return 结果
     */
    int insertQwAppMiniProgramRelation(QwAppMiniProgramRelation qwAppMiniProgramRelation);

    /**
     * 修改应用-小程序关系
     * 
     * @param qwAppMiniProgramRelation 应用-小程序关系
     * @return 结果
     */
    int updateQwAppMiniProgramRelation(QwAppMiniProgramRelation qwAppMiniProgramRelation);

    /**
     * 批量删除应用-小程序关系
     * 
     * @param ids 需要删除的应用-小程序关系主键集合
     * @return 结果
     */
    int deleteQwAppMiniProgramRelationByIds(Long[] ids);

    /**
     * 删除应用-小程序关系信息
     * 
     * @param id 应用-小程序关系主键
     * @return 结果
     */
    int deleteQwAppMiniProgramRelationById(Long id);
}
